@@ -9,5 +9,7 @@
 # roxygen namespace tags. Modify with care!
 ## usethis namespace: start
 #' @useDynLib VC2copula, .registration = TRUE
+#' @import methods
+#' @import copula
 ## usethis namespace: end
-NULL
+"_PACKAGE"
